EXPORTS
	??0CSyncAction@@IAE@AAVCConsoleBase@@AAVOutput@@@Z @ 1 NONAME ; CSyncAction::CSyncAction(class CConsoleBase &, class Output &)
	??0CTestAction@@IAE@AAVCConsoleBase@@AAVOutput@@@Z @ 2 NONAME ; CTestAction::CTestAction(class CConsoleBase &, class Output &)
	??0ConsoleOutput@@QAE@AAVCConsoleBase@@@Z @ 3 NONAME ; ConsoleOutput::ConsoleOutput(class CConsoleBase &)
	??0FileOutput@@QAE@AAVRFile@@@Z @ 4 NONAME ; FileOutput::FileOutput(class RFile &)
	??1CErrorConverter@@UAE@XZ @ 5 NONAME ; CErrorConverter::~CErrorConverter(void)
	??1CScriptSetup@@UAE@XZ @ 6 NONAME ; CScriptSetup::~CScriptSetup(void)
	??1CTestAction@@UAE@XZ @ 7 NONAME ; CTestAction::~CTestAction(void)
	??1CTestHandlerSettings@@QAE@XZ @ 8 NONAME ; CTestHandlerSettings::~CTestHandlerSettings(void)
	??1CTestSetup@@UAE@XZ @ 9 NONAME ; CTestSetup::~CTestSetup(void)
	?AddErrorItem@CErrorConverter@@QAEXABVTDesC16@@ABH@Z @ 10 NONAME ; void CErrorConverter::AddErrorItem(class TDesC16 const &, int const &)
	?AddNextTest@CTestSpec@@UAEHPAVCTestAction@@@Z @ 11 NONAME ; int CTestSpec::AddNextTest(class CTestAction *)
	?AfterOOMFailure@CTestAction@@UAEXXZ @ 12 NONAME ; void CTestAction::AfterOOMFailure(void)
	?CheckResult@CTestAction@@UAEXH@Z @ 13 NONAME ; void CTestAction::CheckResult(int)
	?CompareFileL@Utils@@SAHABVTDesC16@@0AAH@Z @ 14 NONAME ; int Utils::CompareFileL(class TDesC16 const &, class TDesC16 const &, int &)
	?ConstructL@CSyncAction@@IAEXABVTTestActionSpec@@@Z @ 15 NONAME ; void CSyncAction::ConstructL(class TTestActionSpec const &)
	?ConstructL@CTestAction@@IAEXABVTTestActionSpec@@@Z @ 16 NONAME ; void CTestAction::ConstructL(class TTestActionSpec const &)
	?CreateActionL@CScriptSetup@@MBEPAVCTestAction@@AAVRFs@@ABVTTestActionSpec@@QBUTScriptTests@@@Z @ 17 NONAME ; class CTestAction * CScriptSetup::CreateActionL(class RFs &, class TTestActionSpec const &, struct TScriptTests const * const) const
	?CreateAndRunTestsL@CTestSetup@@SAXQAUTHardcodedTests@@ABVTDesC16@@@Z @ 18 NONAME ; void CTestSetup::CreateAndRunTestsL(struct THardcodedTests * const, class TDesC16 const &)
	?CreateAndRunTestsL@CTestSetup@@SAXQAUTScriptTests@@ABVTDesC16@@1HPAVCConsoleBase@@PAH@Z @ 19 NONAME ; void CTestSetup::CreateAndRunTestsL(struct TScriptTests * const, class TDesC16 const &, class TDesC16 const &, int, class CConsoleBase *, int *)
	?DoPerformPostrequisite@CTestAction@@EAEXAAVTRequestStatus@@@Z @ 20 NONAME ; void CTestAction::DoPerformPostrequisite(class TRequestStatus &)
	?DoPerformPrerequisite@CTestAction@@EAEXAAVTRequestStatus@@@Z @ 21 NONAME ; void CTestAction::DoPerformPrerequisite(class TRequestStatus &)
	?FailTestNow@CSyncAction@@MAEXAAVTRequestStatus@@@Z @ 22 NONAME ; void CSyncAction::FailTestNow(class TRequestStatus &)
	?FailTestNow@CTestAction@@UAEXAAVTRequestStatus@@@Z @ 23 NONAME ; void CTestAction::FailTestNow(class TRequestStatus &)
	?GetArgument@CTestSetup@@KAPAVHBufC16@@H@Z @ 24 NONAME ; class HBufC16 * CTestSetup::GetArgument(int)
	?GetExpectedResultL@CErrorConverter@@QAEHABHAAPAVHBufC16@@@Z @ 25 NONAME ; int CErrorConverter::GetExpectedResultL(int const &, class HBufC16 * &)
	?GetExpectedResultL@CErrorConverter@@QAEHABVTDesC16@@AAH@Z @ 26 NONAME ; int CErrorConverter::GetExpectedResultL(class TDesC16 const &, int &)
	?GetExpectedResultL@Input@@SAHABHAAPAVHBufC16@@@Z @ 27 NONAME ; int Input::GetExpectedResultL(int const &, class HBufC16 * &)
	?GetExpectedResultL@Input@@SAHABVTDesC16@@AAH@Z @ 28 NONAME ; int Input::GetExpectedResultL(class TDesC16 const &, int &)
	?GetNextTest@CTestSpec@@UAEHAAPAVCTestAction@@@Z @ 29 NONAME ; int CTestSpec::GetNextTest(class CTestAction * &)
	?InitialiseL@CHardcodedSetup@@QAEHAAVRFs@@ABVTDesC16@@@Z @ 30 NONAME ; int CHardcodedSetup::InitialiseL(class RFs &, class TDesC16 const &)
	?InitialiseL@CScriptSetup@@QAEHAAVRFs@@ABVTDesC16@@1H@Z @ 31 NONAME ; int CScriptSetup::InitialiseL(class RFs &, class TDesC16 const &, class TDesC16 const &, int)
	?NewL@CErrorConverter@@SAPAV1@XZ @ 32 NONAME ; class CErrorConverter * CErrorConverter::NewL(void)
	?NewL@CTestHandlerSettings@@SAPAV1@ABV1@@Z @ 33 NONAME ; class CTestHandlerSettings * CTestHandlerSettings::NewL(class CTestHandlerSettings const &)
	?NewL@CTestSpec@@SAPAV1@XZ @ 34 NONAME ; class CTestSpec * CTestSpec::NewL(void)
	?NewLC@CErrorConverter@@SAPAV1@XZ @ 35 NONAME ; class CErrorConverter * CErrorConverter::NewLC(void)
	?NewLC@CHardcodedSetup@@SAPAV1@XZ @ 36 NONAME ; class CHardcodedSetup * CHardcodedSetup::NewLC(void)
	?NewLC@CScriptSetup@@SAPAV1@PAVCConsoleBase@@@Z @ 37 NONAME ; class CScriptSetup * CScriptSetup::NewLC(class CConsoleBase *)
	?NewLC@CTestHandler@@SAPAV1@AAVRFs@@AAVMTestSpec@@AAVCTestHandlerSettings@@PAVCConsoleBase@@PAVOutput@@@Z @ 38 NONAME ; class CTestHandler * CTestHandler::NewLC(class RFs &, class MTestSpec &, class CTestHandlerSettings &, class CConsoleBase *, class Output *)
	?NewLC@CTestHandlerSettings@@SAPAV1@XZ @ 39 NONAME ; class CTestHandlerSettings * CTestHandlerSettings::NewLC(void)
	?ParseCapabilityNameL@Input@@SA?AW4TCapability@@ABVTDesC8@@@Z @ 40 NONAME ; enum TCapability Input::ParseCapabilityNameL(class TDesC8 const &)
	?ParseCapabilitySetL@Input@@SAXABVTDesC8@@AAVTCapabilitySet@@@Z @ 41 NONAME ; void Input::ParseCapabilitySetL(class TDesC8 const &, class TCapabilitySet &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@00@Z @ 42 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@00AAH1@Z @ 43 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@00AAH@Z @ 44 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, int &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@0@Z @ 45 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@0AAH1@Z @ 46 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseElement@Input@@SA?AVTPtrC16@@ABVTDesC16@@0AAH@Z @ 47 NONAME ; class TPtrC16 Input::ParseElement(class TDesC16 const &, class TDesC16 const &, int &)
	?ParseElement@Input@@SA?AVTPtrC8@@ABVTDesC8@@00@Z @ 48 NONAME ; class TPtrC8 Input::ParseElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &)
	?ParseElement@Input@@SA?AVTPtrC8@@ABVTDesC8@@00AAH1@Z @ 49 NONAME ; class TPtrC8 Input::ParseElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &, int &)
	?ParseElement@Input@@SA?AVTPtrC8@@ABVTDesC8@@00AAH@Z @ 50 NONAME ; class TPtrC8 Input::ParseElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &)
	?ParseElement@Input@@SA?AVTPtrC8@@ABVTDesC8@@0@Z @ 51 NONAME ; class TPtrC8 Input::ParseElement(class TDesC8 const &, class TDesC8 const &)
	?ParseElementBoolL@Input@@SAHABVTDesC8@@0@Z @ 52 NONAME ; int Input::ParseElementBoolL(class TDesC8 const &, class TDesC8 const &)
	?ParseElementHexL@Input@@SAPAVHBufC8@@ABVTDesC8@@0@Z @ 53 NONAME ; class HBufC8 * Input::ParseElementHexL(class TDesC8 const &, class TDesC8 const &)
	?ParseElementL@Input@@SAXAAPAVHBufC16@@ABVTDesC16@@1@Z @ 54 NONAME ; void Input::ParseElementL(class HBufC16 * &, class TDesC16 const &, class TDesC16 const &)
	?ParseElementL@Input@@SAXAAPAVHBufC16@@ABVTDesC16@@1AAH2@Z @ 55 NONAME ; void Input::ParseElementL(class HBufC16 * &, class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseElementL@Input@@SAXAAPAVHBufC16@@ABVTDesC16@@1AAH@Z @ 56 NONAME ; void Input::ParseElementL(class HBufC16 * &, class TDesC16 const &, class TDesC16 const &, int &)
	?ParseElementL@Input@@SAXAAPAVHBufC8@@ABVTDesC16@@1@Z @ 57 NONAME ; void Input::ParseElementL(class HBufC8 * &, class TDesC16 const &, class TDesC16 const &)
	?ParseElementL@Input@@SAXAAPAVHBufC8@@ABVTDesC16@@1AAH2@Z @ 58 NONAME ; void Input::ParseElementL(class HBufC8 * &, class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseElementL@Input@@SAXAAPAVHBufC8@@ABVTDesC16@@1AAH@Z @ 59 NONAME ; void Input::ParseElementL(class HBufC8 * &, class TDesC16 const &, class TDesC16 const &, int &)
	?ParseElementListL@Input@@SAXABVTDesC16@@00AAV?$RPointerArray@VHBufC16@@@@AAH@Z @ 60 NONAME ; void Input::ParseElementListL(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class RPointerArray<class HBufC16> &, int &)
	?ParseIntElement@Input@@SAIABVTDesC16@@00@Z @ 61 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &)
	?ParseIntElement@Input@@SAIABVTDesC16@@00AAH1@Z @ 62 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseIntElement@Input@@SAIABVTDesC16@@00AAH@Z @ 63 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, int &)
	?ParseIntElement@Input@@SAIABVTDesC16@@0@Z @ 64 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &)
	?ParseIntElement@Input@@SAIABVTDesC16@@0AAH1@Z @ 65 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, int &, int &)
	?ParseIntElement@Input@@SAIABVTDesC16@@0AAH@Z @ 66 NONAME ; unsigned int Input::ParseIntElement(class TDesC16 const &, class TDesC16 const &, int &)
	?ParseIntElement@Input@@SAIABVTDesC8@@00@Z @ 67 NONAME ; unsigned int Input::ParseIntElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &)
	?ParseIntElement@Input@@SAIABVTDesC8@@00AAH1@Z @ 68 NONAME ; unsigned int Input::ParseIntElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &, int &)
	?ParseIntElement@Input@@SAIABVTDesC8@@00AAH@Z @ 69 NONAME ; unsigned int Input::ParseIntElement(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &)
	?ParseSecurityPolicyL@Input@@SAXABVTDesC8@@AAVTSecurityPolicy@@@Z @ 70 NONAME ; void Input::ParseSecurityPolicyL(class TDesC8 const &, class TSecurityPolicy &)
	?PerformAction@CSyncAction@@EAEXAAVTRequestStatus@@@Z @ 71 NONAME ; void CSyncAction::PerformAction(class TRequestStatus &)
	?PerformCancel@CTestAction@@UAEXXZ @ 72 NONAME ; void CTestAction::PerformCancel(void)
	?PerformPostrequisite@CTestAction@@UAEXAAVTRequestStatus@@@Z @ 73 NONAME ; void CTestAction::PerformPostrequisite(class TRequestStatus &)
	?PerformPrerequisite@CTestAction@@UAEXAAVTRequestStatus@@@Z @ 74 NONAME ; void CTestAction::PerformPrerequisite(class TRequestStatus &)
	?ReadFileL@Input@@SAPAVHBufC8@@ABVTDesC16@@0AAVRFs@@@Z @ 75 NONAME ; class HBufC8 * Input::ReadFileL(class TDesC16 const &, class TDesC16 const &, class RFs &)
	?ReadFileL@Input@@SAPAVHBufC8@@ABVTDesC16@@AAVRFs@@@Z @ 76 NONAME ; class HBufC8 * Input::ReadFileL(class TDesC16 const &, class RFs &)
	?ReadFileLC@Input@@SAPAVHBufC8@@ABVTDesC16@@0AAVRFs@@@Z @ 77 NONAME ; class HBufC8 * Input::ReadFileLC(class TDesC16 const &, class TDesC16 const &, class RFs &)
	?ReadFileLC@Input@@SAPAVHBufC8@@ABVTDesC16@@AAVRFs@@@Z @ 78 NONAME ; class HBufC8 * Input::ReadFileLC(class TDesC16 const &, class RFs &)
	?ReportAction@CTestAction@@UAEXXZ @ 79 NONAME ; void CTestAction::ReportAction(void)
	?Reset@CTestAction@@UAEXXZ @ 80 NONAME ; void CTestAction::Reset(void)
	?RunTestsL@CTestHandler@@QAEXXZ @ 81 NONAME ; void CTestHandler::RunTestsL(void)
	?ScriptError@CTestAction@@UAE?AW4TScriptError@1@XZ @ 82 NONAME ; enum CTestAction::TScriptError CTestAction::ScriptError(void)
	?ScriptError@CTestAction@@UAEXAAVTDes16@@@Z @ 83 NONAME ; void CTestAction::ScriptError(class TDes16 &)
	?SetScriptError@CTestAction@@UAEXABW4TScriptError@1@ABVTDesC16@@@Z @ 84 NONAME ; void CTestAction::SetScriptError(enum CTestAction::TScriptError const &, class TDesC16 const &)
	?SetSharedData@CTestAction@@IAEXPAVCBase@@@Z @ 85 NONAME ; void CTestAction::SetSharedData(class CBase *)
	?SetupTestsL@CHardcodedSetup@@UAEXAAVRFs@@AAVCTestSpec@@QAUTHardcodedTests@@ABVCTestHandlerSettings@@@Z @ 86 NONAME ; void CHardcodedSetup::SetupTestsL(class RFs &, class CTestSpec &, struct THardcodedTests * const, class CTestHandlerSettings const &)
	?SetupTestsL@CScriptSetup@@UAEXAAVRFs@@AAVCTestSpec@@QAUTScriptTests@@ABVCTestHandlerSettings@@@Z @ 87 NONAME ; void CScriptSetup::SetupTestsL(class RFs &, class CTestSpec &, struct TScriptTests * const, class CTestHandlerSettings const &)
	?SharedData@CTestAction@@IBEPAVCBase@@XZ @ 88 NONAME ; class CBase * CTestAction::SharedData(void) const
	?write@Output@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 89 NONAME ; void Output::write(class TRefByValue<class TDesC16 const >, ...)
	?writeBoolL@Output@@QAEXH@Z @ 90 NONAME ; void Output::writeBoolL(int)
	?writeCapabilityL@Output@@QAEXW4TCapability@@@Z @ 91 NONAME ; void Output::writeCapabilityL(enum TCapability)
	?writeCapabilitySetL@Output@@QAEXABVTCapabilitySet@@@Z @ 92 NONAME ; void Output::writeCapabilitySetL(class TCapabilitySet const &)
	?writeError@Output@@QAEXH@Z @ 93 NONAME ; void Output::writeError(int)
	?writeHex@Output@@QAEXH@Z @ 94 NONAME ; void Output::writeHex(int)
	?writeNewLine@Output@@QAEXXZ @ 95 NONAME ; void Output::writeNewLine(void)
	?writeNum@Output@@QAEXH@Z @ 96 NONAME ; void Output::writeNum(int)
	?writeOctetString@Output@@QAEXABVTDesC8@@@Z @ 97 NONAME ; void Output::writeOctetString(class TDesC8 const &)
	?writeOctetStringL@Output@@QAEXABVTDesC8@@@Z @ 98 NONAME ; void Output::writeOctetStringL(class TDesC8 const &)
	?writeSecurityPolicyL@Output@@QAEXABVTSecurityPolicy@@@Z @ 99 NONAME ; void Output::writeSecurityPolicyL(class TSecurityPolicy const &)
	?writeSpaces@Output@@QAEXH@Z @ 100 NONAME ; void Output::writeSpaces(int)
	?writeString@Output@@QAEXABVTDesC16@@@Z @ 101 NONAME ; void Output::writeString(class TDesC16 const &)
	?writeString@Output@@QAEXABVTDesC8@@@Z @ 102 NONAME ; void Output::writeString(class TDesC8 const &)
	??0NullOutput@@QAE@XZ @ 103 NONAME ; NullOutput::NullOutput(void)
	??0COOMTestRunnerBase@@IAE@AAVOutput@@@Z @ 104 NONAME ; COOMTestRunnerBase::COOMTestRunnerBase(class Output &)
	??0CTestRunner@@QAE@AAVOutput@@@Z @ 105 NONAME ; CTestRunner::CTestRunner(class Output &)
	??1COOMTestRunnerBase@@UAE@XZ @ 106 NONAME ; COOMTestRunnerBase::~COOMTestRunnerBase(void)
	??1CTestRunner@@UAE@XZ @ 107 NONAME ; CTestRunner::~CTestRunner(void)
	?DoCancel@CTestRunner@@EAEXXZ @ 108 NONAME ; void CTestRunner::DoCancel(void)
	?PerformActionL@COOMTestRunnerBase@@EAEHPAVCTestAction@@@Z @ 109 NONAME ; int COOMTestRunnerBase::PerformActionL(class CTestAction *)
	?PerformActionL@CTestRunner@@UAEHPAVCTestAction@@@Z @ 110 NONAME ; int CTestRunner::PerformActionL(class CTestAction *)
	?PerformPostrequisiteL@CTestRunner@@UAEHPAVCTestAction@@H@Z @ 111 NONAME ; int CTestRunner::PerformPostrequisiteL(class CTestAction *, int)
	?PerformPrerequisiteL@CTestRunner@@UAEHPAVCTestAction@@@Z @ 112 NONAME ; int CTestRunner::PerformPrerequisiteL(class CTestAction *)
	?RunError@CTestRunner@@EAEHH@Z @ 113 NONAME ; int CTestRunner::RunError(int)
	?RunL@CTestRunner@@EAEXXZ @ 114 NONAME ; void CTestRunner::RunL(void)
	?SetTestRunnerL@CTestHandler@@QAEXPAVCTestRunner@@@Z @ 115 NONAME ; void CTestHandler::SetTestRunnerL(class CTestRunner *)
	?ResetState@CTestAction@@UAEXXZ @ 116 NONAME ; void CTestAction::ResetState(void)
	?ParseTestCaseID@Tefinput@@SA?AVTPtrC8@@ABVTDesC8@@0AAVTDes8@@AAH222@Z @ 117 NONAME ; class TPtrC8 Tefinput::ParseTestCaseID(class TDesC8 const &, class TDesC8 const &, class TDes8 &, int &, int &, int &, int &)
	?GetiniFile@Tefinput@@SAPAVHBufC8@@AAVRFs@@ABVTDesC16@@AAH@Z @ 118 NONAME ; class HBufC8 * Tefinput::GetiniFile(class RFs &, class TDesC16 const &, int &)
	?Trim@Tefinput@@SA?AVTPtrC8@@ABVTDesC8@@@Z @ 119 NONAME ; class TPtrC8 Tefinput::Trim(class TDesC8 const &)
	?ParseNthElement@Tefinput@@SA?AVTPtrC8@@ABVTDesC8@@HAAH@Z @ 120 NONAME ; class TPtrC8 Tefinput::ParseNthElement(class TDesC8 const &, int, int &)
	?EndTestCase@Tefinput@@SAHABVTDesC8@@00AAH@Z @ 121 NONAME ; int Tefinput::EndTestCase(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, int &)
	?ParseRunTestStep@Tefinput@@SA?AVTPtrC8@@ABVTDesC8@@0AAH1@Z @ 122 NONAME ; class TPtrC8 Tefinput::ParseRunTestStep(class TDesC8 const &, class TDesC8 const &, int &, int &)
	?GetActionResult@Tefinput@@SAHHAAVTDes8@@@Z @ 123 NONAME ; int Tefinput::GetActionResult(int, class TDes8 &)
	?ParseActionResult@Tefinput@@SAHABVTDesC8@@AAVTDes8@@@Z @ 124 NONAME ; int Tefinput::ParseActionResult(class TDesC8 const &, class TDes8 &)
	?TrimActionType@Tefinput@@SA?AVTDes8@@ABVTDesC8@@AAV2@@Z @ 125 NONAME ; class TDes8 Tefinput::TrimActionType(class TDesC8 const &, class TDes8 &)
	?ParseiniPath@Tefinput@@SAHABVTDesC8@@ABVTDesC16@@AAVTDes16@@@Z @ 126 NONAME ; int Tefinput::ParseiniPath(class TDesC8 const &, class TDesC16 const &, class TDes16 &)
	?ParseActionbody@Tefinput@@SAHAAVTPtrC8@@ABVTDesC8@@0@Z @ 127 NONAME ; int Tefinput::ParseActionbody(class TPtrC8 &, class TDesC8 const &, class TPtrC8 &)

